@@ -1,7 +1,7 @@
 #
 # Kenozooid - dive planning and analysis toolbox.
 #
-# Copyright (C) 2009-2013 by Artur Wroblewski <wrobell@pld-linux.org>
+# Copyright (C) 2009-2014 by Artur Wroblewski <wrobell@pld-linux.org>
 #
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -277,7 +277,9 @@ class OSTCDataParser(object):
         """
         status = ostc_parser.get_data(data)
         model = 'OSTC'
-        if status.eeprom.serial > 2047:
+        if status.eeprom.serial > 6999:
+            model = 'OSTC 2C'
+        elif status.eeprom.serial > 2047:
             model = 'OSTC 2N'
         elif status.eeprom.serial > 300:
             model = 'OSTC Mk.2'
